@@ -99,6 +99,7 @@ typedef struct
 
 struct _GeditDBusPrivate
 {
+	guint owner_id;
 	GeditDBusResult result;
 	GMainLoop *main_loop;
 	guint32 wait_id;
@@ -174,6 +175,12 @@ gedit_dbus_dispose (GObject *object)
 	g_clear_object (&dbus->priv->stdin_in_stream);
 #endif
 
+	if (dbus->priv->owner_id != 0)
+	{
+		g_bus_unown_name (dbus->priv->owner_id);
+		dbus->priv->owner_id = 0;
+	}
+
 	G_OBJECT_CLASS (gedit_dbus_parent_class)->dispose (object);
 }
 
@@ -840,7 +847,7 @@ window_from_display_arguments (gboolean           new_window,
 {
 	GdkScreen *screen = NULL;
 	GeditApp *app;
-	GeditWindow *ret;
+	GeditWindow *ret = NULL;
 
 	/* get correct screen using the display_name and screen_number */
 	if (dparams->display_name != NULL && *dparams->display_name)
@@ -854,25 +861,20 @@ window_from_display_arguments (gboolean           new_window,
 
 	app = gedit_app_get_default ();
 
-	if (new_window)
+	if (!new_window)
 	{
-		ret = gedit_app_create_window (app, screen);
-		gedit_window_create_tab (ret, TRUE);
-
-		return ret;
-	}
-
-	if (screen != NULL)
-	{
-		ret = _gedit_app_get_window_in_viewport (app,
-		                                         screen,
-		                                         dparams->workspace == -1 ? 0 : dparams->workspace,
-		                                         dparams->viewport_x == -1 ? 0 : dparams->viewport_x,
-		                                         dparams->viewport_y == -1 ? 0 : dparams->viewport_y);
-	}
-	else
-	{
-		ret = gedit_app_get_active_window (app);
+		if (screen != NULL)
+		{
+			ret = _gedit_app_get_window_in_viewport (app,
+				                                 screen,
+				                                 dparams->workspace == -1 ? 0 : dparams->workspace,
+				                                 dparams->viewport_x == -1 ? 0 : dparams->viewport_x,
+				                                 dparams->viewport_y == -1 ? 0 : dparams->viewport_y);
+		}
+		else
+		{
+			ret = gedit_app_get_active_window (app);
+		}
 	}
 
 	if (!ret)
@@ -1678,16 +1680,18 @@ gedit_dbus_run (GeditDBus *dbus)
 
 	dbus->priv->main_loop = g_main_loop_new (NULL, FALSE);
 
-	g_bus_own_name (G_BUS_TYPE_SESSION,
-	                "org.gnome.gedit",
-	                G_BUS_NAME_OWNER_FLAGS_NONE,
-	                (GBusAcquiredCallback)bus_acquired_cb,
-	                (GBusNameAcquiredCallback)name_acquired_cb,
-	                (GBusNameLostCallback)name_lost_cb,
-	                dbus,
-	                NULL);
+	dbus->priv->owner_id = g_bus_own_name (G_BUS_TYPE_SESSION,
+					       "org.gnome.gedit",
+					       G_BUS_NAME_OWNER_FLAGS_NONE,
+					       (GBusAcquiredCallback)bus_acquired_cb,
+					       (GBusNameAcquiredCallback)name_acquired_cb,
+					       (GBusNameLostCallback)name_lost_cb,
+					       dbus,
+					       NULL);
 
-	gedit_debug_message (DEBUG_DBUS, "Own name org.gnome.gedit\n");
+	gedit_debug_message (DEBUG_DBUS,
+			     "Own name org.gnome.gedit (owner_id = %d)",
+			     dbus->priv->owner_id);
 
 	g_main_loop_run (dbus->priv->main_loop);
 	g_main_loop_unref (dbus->priv->main_loop);
