@@ -133,11 +133,7 @@ gedit_history_entry_dispose (GObject *object)
 	gedit_history_entry_set_enable_completion (GEDIT_HISTORY_ENTRY (object),
 						   FALSE);
 
-	if (priv->settings != NULL)
-	{
-		g_object_unref (G_OBJECT (priv->settings));
-		priv->settings = NULL;
-	}
+	g_clear_object (&priv->settings);
 
 	G_OBJECT_CLASS (gedit_history_entry_parent_class)->dispose (object);
 }
