@@ -547,15 +547,17 @@ build_horizontal_panel (GeditPanel *panel)
 static void
 build_vertical_panel (GeditPanel *panel)
 {
-	GtkWidget *close_button;
+	GtkStyleContext *context;
 	GtkWidget *title_hbox;
 	GtkWidget *icon_name_hbox;
 	GtkWidget *dummy_label;
+	GtkWidget *close_button;
+
+	context = gtk_widget_get_style_context (GTK_WIDGET (panel));
+	gtk_style_context_add_class (context, "title");
 
 	/* Create title hbox */
 	title_hbox = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 6);
-	gtk_widget_set_name (title_hbox, "gedit-panel-title");
-
 	gtk_box_pack_start (GTK_BOX (panel->priv->main_box), title_hbox,
 	                             FALSE, FALSE, 0);
 
@@ -747,7 +749,6 @@ gedit_panel_add_item (GeditPanel  *panel,
 	GeditPanelItem *data;
 	GtkWidget *tab_label;
 	GtkWidget *menu_label;
-	GtkStyleContext *context;
 	gint w, h;
 
 	g_return_val_if_fail (GEDIT_IS_PANEL (panel), FALSE);
@@ -794,13 +795,6 @@ gedit_panel_add_item (GeditPanel  *panel,
 		gtk_widget_show (item);
 	}
 
-	/* Only apply the sidebar style to the side panel */
-	if (panel->priv->orientation == GTK_ORIENTATION_VERTICAL)
-	{
-		context = gtk_widget_get_style_context (item);
-		gtk_style_context_add_class (context, GTK_STYLE_CLASS_SIDEBAR);
-	}
-
 	gtk_notebook_append_page_menu (GTK_NOTEBOOK (panel->priv->notebook),
 				       item,
 				       tab_label,
